@@ -771,7 +771,8 @@ class BigQueryExecutor:
                 sql = read_sql(
                     file=file,
                     from_partition=from_partition,
-                    to_partition=to_partition
+                    to_partition=to_partition,
+                    **kwargs
                 )
 
                 # change date format from YYYY-MM-DD to YYYYMMDD for partition_id 
@@ -783,12 +784,16 @@ class BigQueryExecutor:
 
                 logging.info("Updating partition: %s", partition_name)
                 self.create_table(
+                    project_id=project_id,
                     dataset_id=dataset_id,
                     table_id=partition_name,
-                    schema_path=schema_path,
                     sql=sql,
                     partition=True,
-                    partition_field=partition_field
+                    partition_field=partition_field,
+                    write_disposition=write_disposition,
+                    use_legacy_sql=use_legacy_sql,
+                    clustering=clustering,
+                    priority=priority
                 )
 
         else: # new approach, run backfill
@@ -797,7 +802,8 @@ class BigQueryExecutor:
             sql = read_sql(
                 file=file,
                 from_partition=from_partition,
-                to_partition=to_partition
+                to_partition=to_partition,
+                **kwargs
             )
             self.run_backfill(
                 backfill=os.environ["BACKFILL"],
